%define _prefix /scisoft

Name:           scisoft-miriad
Version:        4.3.7
Release:        1%{?dist}
Summary:        Radio interferometry data reduction package
Distribution:   Scisoft
License:        GPL
Group:          Applications/Scientific
Packager:       Carlos Guirao
URL:            http://carma.astro.umd.edu/miriad/
Source0:        miriad-%{version}.tar.gz

BuildRequires:  libtool
BuildRequires:  flex
BuildRequires:  readline-devel 
BuildRequires:  transfig
BuildRequires:  gnuplot
BuildRequires:  libXaw-devel
BuildRequires:  gcc-gfortran
%if 0%{?fedora} >= 28
BuildRequires:  libtirpc-devel
Requires:       libtirpc
%endif
Requires:       readline 
Requires:       libXaw

%description
Miriad is a radio interferometry data reduction package of particular interest
to users of the Australia Telescope Compact Array (ATCA). It can be used for the
reduction of continuum and spectral line observations from beginning to end,
starting with the loading of the data (either FITS, the ATNF RPFITS or old BIMA
formats) through to image synthesis, analysis and display with publication
quality graphics.

%prep
%setup -q -n miriad

# To let make continue, force it to return 0 after a latex error.
perl -pi -e 's@\$\(LATEX_ARGS\) \$\(srcdir\)/\$\(texname\)@\$\(LATEX_ARGS\) \$\(srcdir\)/\$\(texname\) || exit 0@g' manuals/atnf-prog/Makefile.am
perl -pi -e 's@\$\(LATEX_ARGS\) \$\(srcdir\)/\$\(texname\)@\$\(LATEX_ARGS\) \$\(srcdir\)/\$\(texname\) || exit 0@g' manuals/atnf-user/Makefile.am
perl -pi -e 's@\$\(LATEX_ARGS\) \$\(srcdir\)/\$\(texname\)@\$\(LATEX_ARGS\) \$\(srcdir\)/\$\(texname\) || exit 0@g' manuals/carma/Makefile.am
perl -pi -e 's@\$\(LATEX_ARGS\) \$\(srcdir\)/\$\(texname\)@\$\(LATEX_ARGS\) \$\(srcdir\)/\$\(texname\) || exit 0@g' manuals/carma-cook/Makefile.am

%build
./autogen.sh

%if 0%{?fedora} >= 28 
export CFLAGS="%{optflags} -I/usr/include/tirpc"
export CXXFLAGS="%{optflags} -I/usr/include/tirpc"
export FFLAGS="%{optflags} -std=legacy -I/usr/include/tirpc  -I%{_fmoddir}"
export FCFLAGS="%{optflags} -std=legacy -I/usr/include/tirpc -I%{_fmoddir}"
%else
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
export FFLAGS="%{optflags} -I%{_fmoddir}"
export FCFLAGS="%{optflags} -I%{_fmoddir}"
%endif

export LDFLAGS="%{__global_ldflags}";
# Build to install everything within %{_datadir}/miriad since it brings a number
# internal libraries that conflict with the system.
./configure --prefix=%{_datadir}/miriad F77=gfortran
%make_build

%install
%make_install

# Miriad points to the wrong tcsh:
perl -pi -e "s@/usr/bin/tcsh@/bin/tcsh@" %{buildroot}%{_datadir}/miriad/bin/*

mkdir -p %{buildroot}%{_bindir}
cd %{buildroot}%{_datadir}/miriad/bin
for file in *
do
  # fft and imgen conflict with eclipse so we append -miriad
  case $file in
    fft|imgen|imcat|imwcs|imstack)
       (cd %{buildroot}%{_bindir}; ln -s ../share/miriad/bin/$file `basename $file`-miriad);;
    *)
       (cd %{buildroot}%{_bindir}; ln -s ../share/miriad/bin/$file);;
  esac
done

# Make sure the documentation directory is created.
install -m 755 -d %{buildroot}%{_docdir}/%{name}-%{version}

# Ignore errors due to hardcoded RPATHs.
export QA_RPATHS=2

%files
%dir %{_docdir}/%{name}-%{version}
%doc README.carma
%{_prefix}
%defattr(-,root,root,-)

%changelog
* Mon Mar 19 2018 Artur Szostak <aszostak@partner.eso.org> 4.3.7
- Incorporated into automated build system for Scisoft.
- Updated to use standardised RPM path location macros.

* Mon Oct 24 2016 Artur Szostak <aszostak@partner.eso.org> 4.3.7-2
- Adding gfortran build dependency.

* Wed Nov 13 2013 Carlos Guirao <cguirao@eso.org>
- First integration based on SRPM
